@@ -6,13 +6,13 @@
 
 G_BEGIN_DECLS
 
-/* VOID:ENUM,POINTER (./biji-marshalers.list:1) */
-extern void _biji_marshal_VOID__ENUM_POINTER (GClosure     *closure,
-                                              GValue       *return_value,
-                                              guint         n_param_values,
-                                              const GValue *param_values,
-                                              gpointer      invocation_hint,
-                                              gpointer      marshal_data);
+/* VOID:ENUM,ENUM,POINTER (./biji-marshalers.list:1) */
+extern void _biji_marshal_VOID__ENUM_ENUM_POINTER (GClosure     *closure,
+                                                   GValue       *return_value,
+                                                   guint         n_param_values,
+                                                   const GValue *param_values,
+                                                   gpointer      invocation_hint,
+                                                   gpointer      marshal_data);
 
 /* VOID:BOOLEAN,BOOLEAN (./biji-marshalers.list:2) */
 extern void _biji_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
@@ -22,6 +22,14 @@ extern void _biji_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
+/* VOID:POINTER,ENUM (./biji-marshalers.list:3) */
+extern void _biji_marshal_VOID__POINTER_ENUM (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* ___biji_marshal_MARSHAL_H__ */
