@@ -514,10 +514,11 @@ static void
 handle_mount (BijiOwnCloudProvider *self)
 {
   GFile *root;
+	BijiOwnCloudProviderPrivate *priv = self->priv;
 
   root = NULL;
-  if (G_IS_MOUNT (self->priv->mount))
-    root = g_mount_get_root (self->priv->mount);
+  if (G_IS_MOUNT (priv->mount))
+    root = g_mount_get_root (priv->mount);
 
 
   if (G_IS_FILE (root))
@@ -525,8 +526,9 @@ handle_mount (BijiOwnCloudProvider *self)
     /* OwnCloud Notes folder is not localized.
      * https://github.com/owncloud/notes/issues/7 */
 
-    self->priv->folder = g_file_get_child (root, "Notes");
-    self->priv->monitor = g_file_monitor_directory
+    priv->folder = g_file_get_child (root, "Notes");
+    g_file_make_directory (priv->folder, NULL, NULL);
+    priv->monitor = g_file_monitor_directory
       (self->priv->folder, G_FILE_MONITOR_NONE, NULL, NULL); // cancel, error
 
 
@@ -649,6 +651,7 @@ on_owncloudclient_read (GObject *source_object,
                         gpointer user_data)
 {
   BijiOwnCloudProvider *self = user_data;
+  BijiOwnCloudProviderPrivate *priv = self->priv;
   GFileInputStream *stream;
 	GDataInputStream *reader;
   GError           *error = NULL;
@@ -697,17 +700,39 @@ on_owncloudclient_read (GObject *source_object,
 
   string = g_string_new (buffer);
   g_string_erase (string, 0, 10); // localPath=
-  g_warning ("now, %s", string->str);
 
   /* ok we have the path. Now create the notes */
-  self->priv->path = g_build_filename (string->str, "Notes", NULL);
-  self->priv->folder = g_file_new_for_path (self->priv->path);
-  g_file_enumerate_children_async (self->priv->folder,
-                                   "standard::name,time::modified,time::created", 0,
-                                   G_PRIORITY_DEFAULT,
-                                   NULL,
-                                   enumerate_children_ready_cb,
-                                   self);
+  priv->path = g_build_filename (string->str, "Notes", NULL);
+  priv->folder = g_file_new_for_path (priv->path);
+  g_file_make_directory (priv->folder, NULL, &error);
+
+
+  if (error)
+  {
+    /* This error is not a blocker - the file may already exist. */
+    g_message ("Cannot create %s - %s", priv->path, error->message);
+
+    /* if so, just print the message and go on */
+    if (error->code == G_IO_ERROR_EXISTS)
+    {
+      g_file_enumerate_children_async (priv->folder,
+          "standard::name,time::modified,time::created", 0,
+          G_PRIORITY_DEFAULT,
+          NULL,
+          enumerate_children_ready_cb,
+          self);
+    }
+
+    /* if the creation really failed, fall back to webdav */
+    else
+    {
+      g_warning ("Cannot create %s - trying webdav", priv->path);
+      get_mount (self);
+    }
+
+
+    g_error_free (error);
+  }
 
 
   g_free (buffer);
